EXPORTS
	__14CObexClientMtmR17CRegisteredMtmDllR11CMsvSessionG4TUid @ 1 NONAME ; CObexClientMtm::CObexClientMtm(CRegisteredMtmDll &, CMsvSession &, TUid)
	AddAddresseeL__14CObexClientMtmRC7TDesC16T1 @ 2 NONAME ; CObexClientMtm::AddAddresseeL(TDesC16 const &, TDesC16 const &)
	CommitChangesL__14CObexClientMtm @ 3 NONAME ; CObexClientMtm::CommitChangesL(void)
	ConstructL__14CObexClientMtm @ 4 NONAME ; CObexClientMtm::ConstructL(void)
	ContextEntrySwitched__14CObexClientMtm @ 5 NONAME ; CObexClientMtm::ContextEntrySwitched(void)
	CreateMessageL__14CObexClientMtml @ 6 NONAME ; CObexClientMtm::CreateMessageL(long)
	Find__14CObexClientMtmRC7TDesC16Ui @ 7 NONAME ; CObexClientMtm::Find(TDesC16 const &, unsigned int)
	ForwardL__14CObexClientMtmlUiR14TRequestStatus @ 8 NONAME ; CObexClientMtm::ForwardL(long, unsigned int, TRequestStatus &)
	GetAttachmentSizeL__14CObexClientMtm @ 9 NONAME ; CObexClientMtm::GetAttachmentSizeL(void)
	GetPasswordLC__14CObexClientMtm @ 10 NONAME ; CObexClientMtm::GetPasswordLC(void)
	InvokeSyncFunctionL__14CObexClientMtmiRC18CMsvEntrySelectionR5TDes8 @ 11 NONAME ; CObexClientMtm::InvokeSyncFunctionL(int, CMsvEntrySelection const &, TDes8 &)
	LoadMessageL__14CObexClientMtm @ 12 NONAME ; CObexClientMtm::LoadMessageL(void)
	QueryCapability__14CObexClientMtmG4TUidRi @ 13 NONAME ; CObexClientMtm::QueryCapability(TUid, int &)
	RemoveAddressee__14CObexClientMtmi @ 14 NONAME ; CObexClientMtm::RemoveAddressee(int)
	ReplyL__14CObexClientMtmlUiR14TRequestStatus @ 15 NONAME ; CObexClientMtm::ReplyL(long, unsigned int, TRequestStatus &)
	SaveMessageL__14CObexClientMtm @ 16 NONAME ; CObexClientMtm::SaveMessageL(void)
	SetPasswordL__14CObexClientMtmRC7TDesC16 @ 17 NONAME ; CObexClientMtm::SetPasswordL(TDesC16 const &)
	SetSubjectL__14CObexClientMtmRC7TDesC16 @ 18 NONAME ; CObexClientMtm::SetSubjectL(TDesC16 const &)
	SubjectL__C14CObexClientMtm @ 19 NONAME ; CObexClientMtm::SubjectL(void) const
	ValidateMessage__14CObexClientMtmUi @ 20 NONAME ; CObexClientMtm::ValidateMessage(unsigned int)
	"_._14CObexClientMtm" @ 21 NONAME ; CObexClientMtm::~CObexClientMtm(void)
	AddAddresseeL__14CObexClientMtmRC7TDesC16 @ 22 NONAME ; CObexClientMtm::AddAddresseeL(TDesC16 const &)
	CommitFileNameExternaliseL__14CObexClientMtm @ 23 NONAME R3UNUSED ; CObexClientMtm::CommitFileNameExternaliseL(void)
	ExternaliseFileNameAndHeadersL__14CObexClientMtmRC7TDesC16RC15CObexHeaderList @ 24 NONAME R3UNUSED ; CObexClientMtm::ExternaliseFileNameAndHeadersL(TDesC16 const &, CObexHeaderList const &)
	ExternaliseFileNameL__14CObexClientMtmRC7TDesC16 @ 25 NONAME R3UNUSED ; CObexClientMtm::ExternaliseFileNameL(TDesC16 const &)
	StartFileNameExternaliseL__14CObexClientMtmRC18CMsvEntrySelection @ 26 NONAME R3UNUSED ; CObexClientMtm::StartFileNameExternaliseL(CMsvEntrySelection const &)

